#### Импорт компонента

В файле `composer.json` проекта прописать

    "repositories": {
        "gitlab.iwayex.com/45": {
            "type": "composer",
            "url": "https://gitlab.iwayex.com/api/v4/group/45/-/packages/composer/packages.json"
        }
    }

и выполнить команду `composer require iwaydev/rbac-client`

#### Настройка компонента

В `.env` файлы для каждого стейджа прописываем переменные окружения для доступа к сервису RBAC:

    RBAC_URL=http://api.rbac.local:72
    RBAC_PROJECT_NAME=service
    RBAC_LOGIN=service
    RBAC_PASSWORD=password

Где:

- `RBAC_URL` - URL RBAC
- `RBAC_PROJECT_NAME` - Название текущего проекта, как он прописан в сервисе RBAC
- `RBAC_LOGIN` - Логин текущего проекта, как он прописан в сервисе RBAC
- `RBAC_PASSWORD` - Пароль текущего проекта, как он прописан в сервисе RBAC

В `app.php` файле конфигов прописать:

    /*
    |--------------------------------------------------------------------------
    | Настройки подключения к сервису RBAC
    |--------------------------------------------------------------------------
    */

    'rbac' => [
        'url' => env('RBAC_URL'),
        'projectName' => env('RBAC_PROJECT_NAME'),
        'login' => env('RBAC_LOGIN'),
        'password' => env('RBAC_PASSWORD'),
    ],

В `app.php` файле конфигов зарегистрировать провайдер

    \Rbac\RbacServiceProvider::class,

Выполнить миграции

    make artis q="vendor:publish --provider=\"Rbac\RbacServiceProvider\" --force"
    make artis q="migrate"

В `api.php` файле роутов прописать URL контроллера

    Route::prefix('/v1')->namespace('v1')
        ->group(function () {
            //Конфиги других роутов
            Route::prefix('rbac')->group(function () {
                Route::post('/update-permissions', '\Rbac\Http\Controllers\RbacController@updatePermissions');
            });
        });
    
В классе `EventServiceProvider` в массиве свойства `listen` зарегистрировать события

    /**
     * The event listener mappings for the application.
     *
     * @var array
     */
    protected $listen = [
        //Другие события
        \Rbac\Events\UpdatePermissions::class => [
            \Rbac\Listeners\UpdatePermissions::class
        ]
    ];
    
При необходимости логирования обновления прав доступа настроить канал логирования `rbac_update_permissions` в файле конфигов `logging.php`

Для локального проекта в файле докера `dev.stack.yml` для конейнера `php` в параметре `extra_hosts` укажите `- "api.rbac.local:{{IP_ADDRESS}}"`

Для проверки роли пользователя
    
    \Rbac\Rbac::hasRole(10001, 'test.role')
    \Rbac\Rbac::hasRole(10001, ['test.role', 'test.role2'])

Для проверки доступа пользователя
    
    \Rbac\Rbac::can(10001, 'test.permission')
    \Rbac\Rbac::can(10001, ['test.permission', 'test.permission2'])