<?php

namespace Rbac\Models;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

/**
 * Модель связи прав доступа и ролей
 *
 * Rbac\Models\RolePermission
 *
 * @property integer $id ID
 * @property string $role_name Наименование роли
 * @property string $permission_name Наименование права доступа
 *
 * @method static Builder|RolePermission newModelQuery()
 * @method static Builder|RolePermission newQuery()
 * @method static Builder|RolePermission query()
 * @mixin \Eloquent
 *
 * @property Role $role Роль пользователя
 * @property Permission $permission Права доступа
 */
class RolePermission extends Model
{
    protected $table = 'rbac.roles_permissions';

    /**
     * Отношение для ролей пользователя
     *
     * @return BelongsTo
     */
    public function role()
    {
        return $this->belongsTo(Role::class, 'role_name', 'name');
    }

    /**
     * Отношение для прав доступа
     *
     * @return BelongsTo
     */
    public function permission()
    {
        return $this->belongsTo(Permission::class, 'permission_name', 'name');
    }
}
