<?php

namespace Rbac;

use Rbac\Models\RolePermission;
use Rbac\Models\RoleUser;

/**
 * Основной класс проверки прав доступа
 *
 * Class Rbac
 *
 * @package Rbac
 */
class Rbac
{
    /**
     * Метод проверки роли пользователя
     *
     * @param int $userId ID польователя
     * @param string|array $roles Роли
     *
     * @return bool
     */
    public static function hasRole(int $userId, $roles)
    {
        $roles = is_array($roles) ? $roles : [$roles];
        $roleUsers = RoleUser::query()
            ->select(['role_name'])
            ->where(['user_id' => $userId])
            ->get()
            ->pluck('role_name')
            ->toArray();

        if (empty($roleUsers)) {
            return false;
        }

        return !empty(array_intersect($roles, $roleUsers));
    }

    /**
     * Метод проверки прав доступа пользователя
     *
     * @param int $userId ID польователя
     * @param string|array $permissions Права доступа
     *
     * @return bool
     */
    public static function can(int $userId, $permissions)
    {
        $permissions = is_array($permissions) ? $permissions : [$permissions];

        $rolePermissions = RolePermission::query()
            ->select(['rbac.roles_permissions.permission_name'])
            ->join(
                'rbac.roles_users',
                'rbac.roles_users.role_name',
                '=',
                'rbac.roles_permissions.role_name'
            )
            ->where(['rbac.roles_users.user_id' => $userId])
            ->get()
            ->pluck('permission_name')
            ->toArray();

        if (empty($rolePermissions)) {
            return false;
        }

        return !empty(array_intersect($permissions, $rolePermissions));
    }
}
